#                              -*- Mode: Perl -*- 
# WnErr.pm -- 
# ITIID           : $ITI$ $Header $__Header$
# Author          : Ulrich Pfeifer
# Created On      : Wed May 22 13:18:16 1996
# Last Modified By: Ulrich Pfeifer
# Last Modified On: Thu May 23 15:47:27 1996
# Language        : CPerl
# Update Count    : 24
# Status          : Unknown, Use with caution!
# 
# (C) Copyright 1996, Universität Dortmund, all rights reserved.
# 
# $Locker: pfeifer $
# $Log: WnErr.pm,v $
# Revision 1.1  1996/05/23 13:46:10  pfeifer
# Initial revision
#
# 

package Logfile::WnErr;
require Logfile::Wn;

@ISA = qw(Logfile::Wn);

1;
